%global upstream_name mozjpeg

Name:           libmozjpeg
Version:        2.1
Release:        1%{?dist}
Summary:        SIMD-accelerated JPEG codec that provides both the libjpeg and TurboJPEG APIs

License:        BSD  
URL:            https://github.com/mozilla/mozjpeg 
Source0:        https://github.com/mozilla/mozjpeg/archive/v2.1.tar.gz

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool

%ifarch %{ix86} x86_64
BuildRequires:  nasm
%endif

Conflicts: libjpeg-turbo

%description
%{name} is a JPEG image codec that uses SIMD instructions (MMX, SSE2,
NEON) to accelerate baseline JPEG compression and decompression on x86, x86-64,
and ARM systems.  On such systems, %{name} is generally 2-4x as fast as
libjpeg, all else being equal.  On other types of systems, %{name} can
still outperform libjpeg by a significant amount, by virtue of its
highly-optimized Huffman coding routines.  In many cases, the performance of
%{name} rivals that of proprietary high-speed JPEG codecs.

%{name} implements both the traditional libjpeg API as well as the less
powerful but more straightforward TurboJPEG API.  %{name} also features
colorspace extensions that allow it to compress from/decompress to 32-bit and
big-endian pixel buffers (RGBX, XBGR, etc.), as well as a full-featured Java
interface.

%{name} was forked from libjpeg-turbo.

%package utils
Summary:        Utilities for manipulating JPEG images
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description utils
The %{name}-utils package contains simple client programs for accessing
the libjpeg functions. It contains cjpeg, djpeg, jpegtran, rdjpgcom and
wrjpgcom. Cjpeg compresses an image file into JPEG format. Djpeg decompresses a
JPEG file into a regular image file. Jpegtran can perform various useful
transformations on JPEG files. Rdjpgcom displays any text comments included in a
JPEG file. Wrjpgcom inserts text comments into a JPEG file.


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{upstream_name}-%{version}

%build
autoreconf -fiv
%configure --disable-static
make %{?_smp_mflags}


%install
rm -rf %{buildroot}
%make_install docdir=%{_pkgdocdir} exampledir=%{_pkgdocdir}
find %{buildroot} -name '*.la' -exec rm -f {} ';'

# Fix perms
chmod -x README-turbo.txt

%check
#make test

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc README README-turbo.txt LICENSE.txt
%{_libdir}/libjpeg.so.62*
%{_libdir}/libturbojpeg.so.*
%exclude %{_pkgdocdir}/README-mozilla.txt

%files devel
%doc coderules.txt jconfig.txt libjpeg.txt structure.txt example.c
%{_includedir}/jconfig.h
%{_includedir}/jerror.h
%{_includedir}/jmorecfg.h
%{_includedir}/jpeglib.h
%{_includedir}/turbojpeg.h
%{_libdir}/libjpeg.so
%{_libdir}/libturbojpeg.so

%files utils
%doc usage.txt wizard.txt
%{_bindir}/cjpeg
%{_bindir}/djpeg
%{_bindir}/jpegtran
%{_bindir}/rdjpgcom
%{_bindir}/wrjpgcom
%{_bindir}/tjbench
%{_mandir}/man1/cjpeg.1*
%{_mandir}/man1/djpeg.1*
%{_mandir}/man1/jpegtran.1*
%{_mandir}/man1/rdjpgcom.1*
%{_mandir}/man1/wrjpgcom.1*

%changelog
* Fri Oct 17 2014 Rahul Sundaram <sundaram@fedoraproject.org> - 2.1-1
- initial spec
